@@ -2,7 +2,7 @@
 #
 #   file: lib/Test/Dist/Zilla/Release.pm
 #
-#   Copyright © 2015 Van de Bugger
+#   Copyright © 2015, 2016 Van de Bugger.
 #
 #   This file is part of perl-Test-Dist-Zilla.
 #
@@ -39,7 +39,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin in I<build> action
-our $VERSION = 'v0.4.2_01'; # TRIAL VERSION
+our $VERSION = 'v0.4.2_02'; # TRIAL VERSION
 
 use Test::Routine;
 
@@ -111,7 +111,7 @@ test Release => sub {
 #pod     use warnings;
 #pod
 #pod     use Path::Tiny;
-#pod     use Test::Deep qw{ cmp_deeply };
+#pod     use Test::Deep qw{ cmp_deeply re };
 #pod     use Test::More;
 #pod     use Test::Routine;
 #pod     use Test::Routine::Util;
@@ -168,7 +168,7 @@ test Release => sub {
 #pod         expected => {
 #pod             messages => [
 #pod                 'Created directory releases',
-#pod                 'Moved to releases/Dummy-0.003.tar.gz',
+#pod                 re( 'Moved to releases[/\\]Dummy-0\.003\.tar\.gz' ),
 #pod             ],
 #pod             archive => 'releases/Dummy-0.003.tar.gz',
 #pod         },
@@ -181,7 +181,7 @@ test Release => sub {
 #pod         expected => {
 #pod             messages => [
 #pod                 'Created directory .archive',
-#pod                 'Moved to .archive/Dummy-0.003.tar.gz',
+#pod                 re( 'Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz' ),
 #pod             ],
 #pod             archive => '.archive/Dummy-0.003.tar.gz',
 #pod         },
@@ -200,7 +200,7 @@ test Release => sub {
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
-#pod Copyright (C) 2015 Van de Bugger
+#pod Copyright (C) 2015, 2016 Van de Bugger
 #pod
 #pod License GPLv3+: The GNU General Public License version 3 or later
 #pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
@@ -225,7 +225,7 @@ Test::Dist::Zilla::Release - Test your Dist::Zilla plugin in I<build> action
 
 =head1 VERSION
 
-Version v0.4.2_01, released on 2016-11-11 20:48 UTC.
+Version v0.4.2_02, released on 2016-11-21 20:04 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
@@ -236,7 +236,7 @@ This is a B<trial release>.
     use warnings;
 
     use Path::Tiny;
-    use Test::Deep qw{ cmp_deeply };
+    use Test::Deep qw{ cmp_deeply re };
     use Test::More;
     use Test::Routine;
     use Test::Routine::Util;
@@ -293,7 +293,7 @@ This is a B<trial release>.
         expected => {
             messages => [
                 'Created directory releases',
-                'Moved to releases/Dummy-0.003.tar.gz',
+                re( 'Moved to releases[/\\]Dummy-0\.003\.tar\.gz' ),
             ],
             archive => 'releases/Dummy-0.003.tar.gz',
         },
@@ -306,7 +306,7 @@ This is a B<trial release>.
         expected => {
             messages => [
                 'Created directory .archive',
-                'Moved to .archive/Dummy-0.003.tar.gz',
+                re( 'Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz' ),
             ],
             archive => '.archive/Dummy-0.003.tar.gz',
         },
@@ -361,7 +361,7 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Van de Bugger
+Copyright (C) 2015, 2016 Van de Bugger
 
 License GPLv3+: The GNU General Public License version 3 or later
 <http://www.gnu.org/licenses/gpl-3.0.txt>.
